# Introduction

The purpose of this library is to wrap up all the communication details 
of using the Brightcove 3 Media APIs so that the developer using the 
library can focus on just writing Python.


### Links

* [Media API Reference](http://help.brightcove.com/developer/docs/mediaapi/media-API.cfm)
